<?php
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Crypt;

if (!function_exists('_encryptString')) {
  function _encryptString($password) {
    return Crypt::encryptString($password);
  }
}

if (!function_exists('_decryptString')) {
  function _decryptString($password) {
    return Crypt::decryptString($password);
  }
}

if (!function_exists('_isImage')) {
  function _isImage($filename)  {
    $allowedExtensions = ['jpg', 'jpeg', 'png', 'gif', 'bmp']; // List of allowed image extensions
    $extension = strtolower(pathinfo($filename, PATHINFO_EXTENSION));
    return in_array($extension, $allowedExtensions);
  }
}

if (!function_exists('_getExtension')) {
  function _getExtension($filename)  {
    return pathinfo($filename, PATHINFO_EXTENSION);
  }
}

if (!function_exists('_uploadOriginalFileName')) {
  function _uploadOriginalFileName($file, $destination)  {
    $filename = $file->getClientOriginalName();
    $filePath = $file->storeAs($destination, $filename);
    return $filename;
  }
}

if (!function_exists('_uploadFile')) {
  function _uploadFile($file, $destination, $prefix = '') {
    $extension = $file->getClientOriginalExtension();
    $characters = '01abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $customName = substr(str_shuffle($characters), 0, 6);

    $filename = $prefix.''.$customName . '.' . $extension;
    $filePath = $file->storeAs($destination, $filename);
    return $filename;
  }
}

if (!function_exists('_mobileLink')) {
  function _mobileLink($mobile)  {
    $mobile = keepDigits($mobile);
    $format = (!empty($mobile)) ? preg_replace("/^(\d{3})(\d{3})(\d{4})$/", "($1) $2-$3", $mobile) : "";
    return (!empty($mobile)) ? '<a href="tel:'.$mobile.'">'.$format.'</a>' : "-";
  }
}

if (!function_exists('_emailLink')) {
  function _emailLink($email)  {
    return (!empty($email)) ? '<a href="mailto:'.$email.'">'.$email.'</a>' : "-";
  }
}

if (!function_exists('_mobile')) {
  function _mobile($mobile) {
    $mobile = keepDigits($mobile);
    return (!empty($mobile)) ? preg_replace("/^(\d{3})(\d{3})(\d{4})$/", "($1) $2-$3", $mobile) : "-";
  }
}

if (!function_exists('keepDigits')) {
  function keepDigits($string) {
    return preg_replace('/\D/', '', $string);
  }
}

if (!function_exists('_date1')) {
  function _date1($date) {
    return (!empty($date)) ? date('m-d-Y', strtotime($date)) : "-";
  }
}

if (!function_exists('_date')) {
  function _date($date) {
    return (!empty($date)) ? date('F j, Y', strtotime($date)) : "-";
  }
}

if (!function_exists('_dateTime')) {
  function _dateTime($date) {
    return (!empty($date)) ? date('F j, Y H:i:s A', strtotime($date)) : "-";
  }
}

if (!function_exists('currentDate')) {
  function currentDate()  {
    $currentDateTime = \Carbon\Carbon::now();
    return $currentDateTime->format('Y-m-d H:i:s');
  }
}