<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\Users;
use Illuminate\Support\Facades\File;
use DB;
use Carbon\Carbon; 
use Mail; 
use Illuminate\Support\Str;

class UserController extends Controller {
	public function login(Request $request) {
		try {
			$data['pageTitle'] = 'Login';
			return view('login', compact('data'));
		} catch(\Exception $e) {}
	}

	public function checkLogin(Request $request) {
		$output = array();
		try {
			$validator = Validator::make($request->all(), [
				'username' => 'required',
				'password' => 'required',
			]);

			if ($validator->fails()) {
				$output['error'] = $validator->errors()->all();
				$output['statusCode'] = '500';
			} else {
				$isExists = Users::where('username', $request->username)
										->where('isDeleted', '0')
										->first();

        if ($isExists && _decryptString($isExists->password) === $request->password) {
          Auth::guard('admin')->login($isExists);
          session(['loginID' => $isExists->id, 'loginInfo' => $isExists]);
          
          $output['message'] = "Welcome back! You're logged in successfully.!";
          $output['statusCode'] = '200';
        } else {
          $output['error'] = 'User not Found !';
          $output['statusCode'] = '500';
        }
      }
		} catch(\Exception $e) {
			$output['error'] = $e->getMessage();
			$output['statusCode'] = '500';
		}

		return response()->json($output);
	}

	public function myProfile() {
		try {
			$data['pageTitle'] = 'My Profile';
			return view('myprofile', compact('data'));
		} catch(\Exception $e) {}		
	}

	public function changePassword(Request $request) {
		try {
			$data['pageTitle'] = 'Change Password';
			return view('change_password', compact('data'));
		} catch(\Exception $e) {}
	}

	public function updateProfile(Request $request) {
		try {
			$loginID = session('loginID');
			$request->validate([
				'name' => 'required|max:255',
				'username' => 'required|max:255',
				'email' => 'required|email',
				'mobile' => 'required',			
			]);

			$existses = session('loginInfo');
			$imageName = '';

			if(!empty($request->profile)){
				$imagePath = public_path('assets/images/users/'.$existses->profile);
				if (File::exists($imagePath)) {
					File::delete($imagePath);
				} 
				$imageName = time().'.'.$request->profile->extension();
				$request->profile->move(public_path('assets/images/users'), $imageName);
			}
						
			$user = Users::findOrFail($loginID);
			$user->name = $request->input('name');
			$user->username = $request->input('username');
			$user->profile = (!empty($imageName)) ? $imageName : $existses->profile;
			$user->email = $request->input('email');
			$user->mobile = $request->input('mobile');
			$user->save();

			$isExists = Users::where('id', $loginID)->first();
			session(['loginInfo' => $isExists]);
			return redirect()->route('myProfile')->with('success', 'Profile was updated successfully.');
		} catch(\Exception $e) {
			return back()->with('error', 'There was a problem uploading the file.');
		}
	}

	public function saveChangePassword(Request $request) {
		$output = array();
		try {
			$validator = Validator::make($request->all(), [
				'oldPassword' => 'required',
				'newPassword' => 'required',
			]);

			if ($validator->fails()) {
				$output['error'] = $validator->errors()->all();
				$output['statusCode'] = '500';
			} else {
				$loginID = session('loginID');
				$newPassword = _encryptString($request->newPassword);
				$isExists = Users::where('id', $loginID)
													->first();

				if ($isExists && _decryptString($isExists->password) === $request->oldPassword) {
					$user = Users::find($loginID);
					$user->update([
						'password' => $newPassword,
						'updated_at' => currentDate(),
						'updatedBy' => $loginID,
					]);
					$output['message'] = "Your password has been changed successfully.";
					$output['statusCode'] = '200';
				} else {
					$output['error'] = 'Old Password does not match !';
					$output['statusCode'] = '500';
				}
			}
		} catch(\Exception $e) {
			$output['error'] = $e->getMessage();
			$output['statusCode'] = '500';
		}
		return response()->json($output);
	}

	public function logout(Request $request) {
		try {
			Auth::guard('admin')->logout();
			session()->forget('loginID');
			session()->forget('loginInfo');
			$url = route('login');
			return redirect($url);
		} catch(\Exception $e) {
			echo $e->getMessage();
		}
	}

	public function checkUserEmail(Request $request) {
		$output = array();
		try {
			$validated = $request->validate([
				'email' => 'required|email|exists:users',
			]);
			
			if (!$validated) {
				$output['error'] = $validated;
				$output['statusCode'] = '500';
			} else {
				$isExists = Users::where('email', $request->email)
										->where('isDeleted', '0')
										->first();

				if(empty($isExists)) {
					$output['error'] = 'Email not Found !';
					$output['statusCode'] = '500';
				} else {
					$token = Str::random(64);
					DB::table('password_resets')->insert([
						'email' => $request->email, 
						'token' => $token, 
						'created_at' => Carbon::now()
					]);
		  
					Mail::send('email.forgetPassword', ['token' => $token], function($message) use($request){
						$message->to($request->email);
						$message->subject('Reset Password');
					});
					
					$output['statusCode'] = '200';
					$output['message'] = 'Reset Password Mail sent to your E-Mail ID ';
				}
			}			
		} catch(\Exception $e) {
			$output['error'] = $e->getMessage();
			$output['statusCode'] = '500';
		}

		return response()->json($output);
	}

	public function showResetPasswordForm($token) { 
		try {
			$data['pageTitle'] = "Reset Password";
			$data['token'] = $token;
			return view('forgot_password_link', compact('data'));
		} catch(\Exception $e) {}
	}

	public function submitResetPasswordForm(Request $request) {
		$output = array();
		try {
			$validated = $request->validate([
				'email'=>'required|email|exists:users',
				'password' => 'required|string|min:6|confirmed',
				'password_confirmation' => 'required'		 
			]);
			
			if (!$validated) {
				$output['error'] = $validated;
				$output['statusCode'] = '500';
			} else {
				$updatePassword = DB::table('password_resets')->where(['email' => $request->email,'token' => $request->token])->first();
				
				if(empty($updatePassword)){
					$output['error'] = 'Invalid Token!';
					$output['statusCode'] = '500';
				}else{
					$user = Users::where('email', $request->email)->update(['password' => _encryptString($request->password)]);	
					DB::table('password_resets')->where(['email'=> $request->email])->delete();
					$output['statusCode'] = '200';
				}
			}
		}catch(\Exception $e) {
			$output['error'] = $e->getMessage();
			$output['statusCode'] = '500';
		}

		return response()->json($output);
	}
}